@@ -1,7 +1,7 @@
 """
 Type annotations for secretsmanager service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_secretsmanager/type_defs/)
 
 Usage::
 
@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import FilterNameStringTypeType, SortOrderTypeType, StatusTypeType
 
@@ -45,6 +46,7 @@ __all__ = (
     "GetSecretValueResponseTypeDef",
     "ListSecretVersionIdsRequestRequestTypeDef",
     "ListSecretVersionIdsResponseTypeDef",
+    "ListSecretsRequestListSecretsPaginateTypeDef",
     "ListSecretsRequestRequestTypeDef",
     "ListSecretsResponseTypeDef",
     "PaginatorConfigTypeDef",
@@ -335,6 +337,16 @@ ListSecretVersionIdsResponseTypeDef = TypedDict(
     },
 )
 
+ListSecretsRequestListSecretsPaginateTypeDef = TypedDict(
+    "ListSecretsRequestListSecretsPaginateTypeDef",
+    {
+        "Filters": Sequence["FilterTypeDef"],
+        "SortOrder": SortOrderTypeType,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListSecretsRequestRequestTypeDef = TypedDict(
     "ListSecretsRequestRequestTypeDef",
     {
